==> haskell-crypto-pubkey-types-0.4.3-241-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-1jue2bVpWpdDd02no65DKZ
key:                  crypto-pubkey-types-0.4.3-1jue2bVpWpdDd02no65DKZ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  7fc3709732ff918e2407a9dc55028917
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/crypto-pubkey-types-0.4.3
hs-libraries:         HScrypto-pubkey-types-0.4.3-1jue2bVpWpdDd02no65DKZ
depends:
    asn1-encoding-0.9.6-K0cg6RPoc9UAXeOM32bjnP
    asn1-types-0.3.4-53HN1R8hr728RtsioOHpIO base-4.15.0.0

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-I0nPYML08n3HETLQfVU95o
key:                  crypto-pubkey-types-0.4.3-I0nPYML08n3HETLQfVU95o
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  fae974f2e3f1eb3a1e76ae72d22b281c
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/crypto-pubkey-types-0.4.3
hs-libraries:         HScrypto-pubkey-types-0.4.3-I0nPYML08n3HETLQfVU95o
depends:
    asn1-encoding-0.9.6-rIHeKAJRWrG7RR5aenGoz
    asn1-types-0.3.4-3XNrXgOwxk5IUBKIztjceO base-4.15.0.0

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
